@@ -290,7 +290,7 @@ interactive.uncertainty.illustration <- function(log.level = NULL) {
                         shiny::h4("About"),
                         shiny::p("This app is an interactive version of the graphical tool proposed by 'Exploiting disagreement between high-dimensional variable selectors for uncertainty visualization'. The graphical tool visualizes the variable selection uncertainty via the method introduced by the paper."),
                         shiny::p("The aim of this app is to provide users a taste of how the tool can help visualizing uncertainties, and how the tool may be helpful for their data analysis. In this app, users can try out the visualization tool using their own data and compare the new method with some popular variable selection methods. Users can also use this app to visualize the variable selection uncertainty of the data they have and have some idea which variables are possibly more important."),
-                        shiny::p("Note that this shiny app is only a 'teste': it is designed to process datasets that are relatively small. This app may not be efficient or have enough compacity to handle some larger datasets. For users who want to use the method and visualization tool to analyse a big dataset, please use the [fuction todo] in the 'CSUV' R package"),
+                        shiny::p("Note that this shiny app is only a 'teste': it is designed to process datasets that are relatively small. This app may not be efficient or have enough compacity to handle some larger datasets. For users who want to use the method and visualization tool to analyse a big dataset, please use the csuv in the 'CSUV' R package"),
                         shiny::br(),
                         shiny::h4("Author"),
                         shiny::p("Christine Yuen (yuenl@lse.ac.uk)")
